### Sample source file for Time Series course
### Yan Liu, 2018/10/12

# set working directory
wd <- setwd("D:/WHU/Under/TS18/R")

data0  <- read.csv("CMTS_quarterly.csv")
tsdata <- ts(data = data0, start = c(1992, 1), frequency = 4)
logY   <- tsdata[, "logrealGDP_va"]

plot(logY,
     xlab = "",
     ylab = "",
     main = "log real GDP")
acf(logY)
pacf(logY)

plot(diff(logY, lag = 1),
     xlab = "",
     ylab = "",
     main = "Real GDP: Q to Q")
acf(diff(logY, lag = 1))
pacf(diff(logY, lag = 1))

plot(diff(logY, lag = 4),
     xlab = "",
     ylab = "",
     main = "Real GDP: Y to Y")
acf(diff(logY, lag = 4))
pacf(diff(logY, lag = 4))

alpha <- (logY[105] - logY[1]) / 104
logYd <- logY - alpha * c(0:104)
plot(logYd,
     xlab = "",
     ylab = "",
     main = "log real GDP: linear detrend")
acf(logYd)
pacf(logYd)

## A simulation example
# A short sample
wn <- rnorm(100)
rw <- wn # first set rw to be wn
for (i in 2:100) {
  rw[i] <- rw[i-1] + wn[i]
}
wn <- as.ts(data = wn)
rw <- as.ts(data = rw)
plot(wn, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "White noise")
plot(rw, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "Random walk")
acf(rw)
pacf(rw)

mu <- 0.1
for (i in 2:100) {
  rw[i] <- rw[i-1] + wn[i] + mu
}
wn <- as.ts(data = wn)
rw <- as.ts(data = rw)
plot(wn, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "White noise")
plot(rw, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "Random walk with drift")
acf(rw)
pacf(rw)

# A longer one
wn <- rnorm(1000)
rw <- wn # first set rw to be wn
for (i in 2:1000) {
  rw[i] <- rw[i-1] + wn[i]
}
wn <- as.ts(data = wn)
rw <- as.ts(data = rw)
plot(wn, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "White noise")
plot(rw, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "Random walk")
acf(rw)
pacf(rw)

mu <- 0.1
for (i in 2:1000) {
  rw[i] <- rw[i-1] + wn[i] + mu
}
wn <- as.ts(data = wn)
rw <- as.ts(data = rw)
plot(wn, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "White noise")
plot(rw, type = "l", col = "blue", 
     xlab = "", ylab = "", main = "Random walk with drift")
acf(rw)
pacf(rw)
